@@ -8,7 +8,7 @@ def pushcode(src:str, dst:str, base:str, new:str) -> None:
 rm -rf {folder}
 mkdir -p {folder}/code
 cd {folder}
-cp -r {src} .
+ln -s {src} code
 cat > Dockerfile << EOF
 FROM {base}
 ADD code {dst}
@@ -16,7 +16,5 @@ EOF
 docker image rm -f {new}
 docker build -t {new} .
 cd ~
-rm -rf {folder}
-docker image ls
 ''')
 
